pub struct TransportConfig {
pub(crate) protocols: Vec<PtTransportName>,
pub(crate) path: Option<CfgPath>,
pub(crate) arguments: Vec<String>,
pub(crate) proxy_addr: Option<SocketAddr>,
pub(crate) run_on_startup: bool,
}Expand description
A single pluggable transport.
Pluggable transports are programs that transform and obfuscate traffic on the network between a Tor client and a Tor bridge, so that an adversary cannot recognize it as Tor traffic.
A pluggable transport can be either managed (run as an external process that we launch and monitor), or unmanaged (running on a local port, not controlled by Arti).
Fields
protocols: Vec<PtTransportName>Names of the transport protocols that we are willing to use from this transport.
(These protocols are arbitrary identifiers that describe which protocols we want. They must match names that the binary knows how to provide.)
path: Option<CfgPath>The path to the binary to run, if any.
This needs to be the path to some executable file on disk.
Present only for managed transports.
arguments: Vec<String>One or more command-line arguments to pass to the binary.
Meaningful only for managed transports.
proxy_addr: Option<SocketAddr>The location at which to contact this transport.
Present only for unmanaged transports.
run_on_startup: boolIf true, launch this transport on startup. Otherwise, we launch it on demand.
Meaningful only for managed transports.
Implementations
Sourceimpl TransportConfig
impl TransportConfig
Sourcepub fn builder() -> TransportConfigBuilder
pub fn builder() -> TransportConfigBuilder
Return a new [TransportConfig Builder] to construct an instance of this type.