#[non_exhaustive]pub enum PtMessage {
Show 14 variants
VersionError(String),
Version(String),
EnvError(String),
ProxyDone,
ProxyError(String),
ClientTransportLaunched {
transport: PtTransportName,
protocol: String,
endpoint: SocketAddr,
},
ClientTransportFailed {
transport: PtTransportName,
message: String,
},
ClientTransportsDone,
ServerTransportLaunched {
transport: PtTransportName,
endpoint: SocketAddr,
options: HashMap<String, String>,
},
ServerTransportFailed {
transport: PtTransportName,
message: String,
},
ServerTransportsDone,
Log {
severity: String,
message: String,
},
Status(PtStatus),
Unknown(String),
}managed-pts only.Expand description
A message sent from a pluggable transport child process.
For more in-depth information about these messages, consult pt-spec.txt.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
VersionError(String)
VERSION-ERROR: No compatible pluggable transport specification version was provided.
Version(String)
VERSION: Specifies the version the binary is using for the IPC protocol.
EnvError(String)
ENV-ERROR: Reports an error with the provided environment variables.
ProxyDone
PROXY DONE: The configured proxy was correctly initialised.
ProxyError(String)
PROXY-ERROR: An error was encountered setting up the configured proxy.
ClientTransportLaunched
CMETHOD: A client transport has been launched.
Fields
transport: PtTransportNameThe name of the launched transport.
endpoint: SocketAddrAn address to connect via this transport. (This should be localhost.)
ClientTransportFailed
CMETHOD-ERROR: An error was encountered setting up a client transport.
ClientTransportsDone
CMETHODS DONE: All client transports that are supported have been launched.
ServerTransportLaunched
SMETHOD: A server transport has been launched.
Fields
transport: PtTransportNameThe name of the launched transport.
endpoint: SocketAddrThe endpoint clients should use the reach the transport.
ServerTransportFailed
SMETHOD-ERROR: An error was encountered setting up a server transport.
ServerTransportsDone
SMETHODS DONE: All server transports that are supported have been launched.
Log
LOG: A log message.
Fields
Status(PtStatus)
STATUS: Arbitrary key/value status messages.
Unknown(String)
A line containing an unknown command.