pub struct PtCommonParametersBuilder {
state_location: Option<PathBuf>,
outbound_bind_v4: Option<Option<Ipv4Addr>>,
outbound_bind_v6: Option<Option<Ipv6Addr>>,
timeout: Option<Option<Duration>>,
}Expand description
Builder for PtCommonParameters.
Fields
state_location: Option<PathBuf>A path where the launched PT can store state.
outbound_bind_v4: Option<Option<Ipv4Addr>>An IPv4 address to bind outgoing connections to (if specified).
Leaving this out will mean the PT uses a sane default.
outbound_bind_v6: Option<Option<Ipv6Addr>>An IPv6 address to bind outgoing connections to (if specified).
Leaving this out will mean the PT uses a sane default.
timeout: Option<Option<Duration>>The maximum time we should wait for a pluggable transport binary to report successful
initialization. If None, a default value is used.
Implementations
Sourceimpl PtCommonParametersBuilder
impl PtCommonParametersBuilder
Sourcepub fn state_location(&mut self, value: PathBuf) -> &mut Self
pub fn state_location(&mut self, value: PathBuf) -> &mut Self
A path where the launched PT can store state.
Sourcepub fn outbound_bind_v4(&mut self, value: Option<Ipv4Addr>) -> &mut Self
pub fn outbound_bind_v4(&mut self, value: Option<Ipv4Addr>) -> &mut Self
An IPv4 address to bind outgoing connections to (if specified).
Leaving this out will mean the PT uses a sane default.
Sourcepub fn outbound_bind_v6(&mut self, value: Option<Ipv6Addr>) -> &mut Self
pub fn outbound_bind_v6(&mut self, value: Option<Ipv6Addr>) -> &mut Self
An IPv6 address to bind outgoing connections to (if specified).
Leaving this out will mean the PT uses a sane default.
Sourcepub fn timeout(&mut self, value: Option<Duration>) -> &mut Self
pub fn timeout(&mut self, value: Option<Duration>) -> &mut Self
The maximum time we should wait for a pluggable transport binary to report successful
initialization. If None, a default value is used.
Sourcepub fn build(
&self,
) -> Result<PtCommonParameters, PtCommonParametersBuilderError>
pub fn build( &self, ) -> Result<PtCommonParameters, PtCommonParametersBuilderError>
Sourcefn create_empty() -> Self
fn create_empty() -> Self
Create an empty builder, with all fields set to None or PhantomData.