pt_identifier

Function pt_identifier 

pub(crate) fn pt_identifier(
    binary_path: impl AsRef<Path>,
) -> Result<String, PtError>
Given a path to a binary for a pluggable transport, return an identifier for that binary in human-readable form.