pub(crate) struct PtReactor<R> {
rt: R,
running: Vec<PluggableClientTransport>,
requests: HashMap<PtTransportName, Vec<Sender<Result<PtClientMethod>>>>,
spawning: FuturesUnordered<Pin<Box<dyn Future<Output = (Vec<PtTransportName>, Result<PluggableClientTransport>)> + Send>>>,
state: Arc<RwLock<PtSharedState>>,
rx: UnboundedReceiver<PtReactorMessage>,
state_dir: PathBuf,
path_resolver: Arc<CfgPathResolver>,
}Expand description
Background reactor to handle managing pluggable transport binaries.
Fields
rt: RRuntime.
running: Vec<PluggableClientTransport>Currently running pluggable transport binaries.
requests: HashMap<PtTransportName, Vec<Sender<Result<PtClientMethod>>>>A map of asked-for transports.
If a transport name has an entry, we will append any additional requests for that entry. If no entry is present, we will start a request.
spawning: FuturesUnordered<Pin<Box<dyn Future<Output = (Vec<PtTransportName>, Result<PluggableClientTransport>)> + Send>>>FuturesUnordered that spawned tasks get pushed on to.
WARNING: This MUST always contain one “will never resolve” future!
state: Arc<RwLock<PtSharedState>>State for the corresponding PtMgr.
rx: UnboundedReceiver<PtReactorMessage>PtMgr channel. (Unbounded so that we can reconfigure without blocking: we’re unlikely to have the reactor get behind.)
state_dir: PathBufState directory.
path_resolver: Arc<CfgPathResolver>Path resolver for configuration files.
Implementations
Sourceimpl<R: Runtime> PtReactor<R>
impl<R: Runtime> PtReactor<R>
Sourcepub(crate) fn new(
rt: R,
state: Arc<RwLock<PtSharedState>>,
rx: UnboundedReceiver<PtReactorMessage>,
state_dir: PathBuf,
path_resolver: Arc<CfgPathResolver>,
) -> Self
pub(crate) fn new( rt: R, state: Arc<RwLock<PtSharedState>>, rx: UnboundedReceiver<PtReactorMessage>, state_dir: PathBuf, path_resolver: Arc<CfgPathResolver>, ) -> Self
Make a new reactor.
Sourcefn handle_spawned(
&mut self,
covers: Vec<PtTransportName>,
result: Result<PluggableClientTransport>,
)
fn handle_spawned( &mut self, covers: Vec<PtTransportName>, result: Result<PluggableClientTransport>, )
Called when a spawn request completes.
Sourcefn remove_pt(&self, pt: PluggableClientTransport)
fn remove_pt(&self, pt: PluggableClientTransport)
Called to remove a pluggable transport from the shared state.
Sourcepub(crate) async fn run_one_step(&mut self) -> Result<bool>
pub(crate) async fn run_one_step(&mut self) -> Result<bool>
Run one step of the reactor. Returns true if the reactor should terminate.