type SpawnResult = (Vec<PtTransportName>, Result<PluggableClientTransport>);Expand description
The result of a spawn attempt: the list of transports the spawned binary covers, and the result.
type SpawnResult = (Vec<PtTransportName>, Result<PluggableClientTransport>);The result of a spawn attempt: the list of transports the spawned binary covers, and the result.