pub struct PtServerParametersBuilder { /* private fields */ }Available on crate feature
managed-pts only.Expand description
Builder for PtServerParameters.
Implementations
Sourceimpl PtServerParametersBuilder
impl PtServerParametersBuilder
Sourcepub fn transports(&mut self, value: Vec<PtTransportName>) -> &mut Self
pub fn transports(&mut self, value: Vec<PtTransportName>) -> &mut Self
A list of transports to initialise.
The PT launch will fail if all transports are not successfully initialised.
Sourcepub fn server_transport_options(&mut self, value: String) -> &mut Self
pub fn server_transport_options(&mut self, value: String) -> &mut Self
Transport options for each server transport
Sourcepub fn server_bindaddr(&mut self, value: String) -> &mut Self
pub fn server_bindaddr(&mut self, value: String) -> &mut Self
Set host:port on which the server transport should listen for connections
Sourcepub fn server_orport(&mut self, value: Option<String>) -> &mut Self
pub fn server_orport(&mut self, value: Option<String>) -> &mut Self
Set host:port on which the server transport should forward requests
Sourcepub fn server_extended_orport(&mut self, value: Option<String>) -> &mut Self
pub fn server_extended_orport(&mut self, value: Option<String>) -> &mut Self
Set host:port on which the server transport should forward requests (extended ORPORT)
Sourcepub fn build(
&self,
) -> Result<PtServerParameters, PtServerParametersBuilderError>
pub fn build( &self, ) -> Result<PtServerParameters, PtServerParametersBuilderError>