fn pt_identifier_as_path( binary_path: impl AsRef<Path>, ) -> Result<PathBuf, PtError>
Given a path to a binary for a pluggable transport, return an identifier for that binary in a format that can be used as a path component.